@@ -35,8 +35,6 @@ typedef struct {
 	gboolean no_server;
 	GIOStream *raw_server;
 
-	GList *initial_cookies;
-
 	GMutex mutex;
 } Test;
 
@@ -218,19 +216,10 @@ client_connect (Test *test,
 		gpointer user_data)
 {
 	char *url;
-	SoupCookieJar *jar;
-	GList *l;
 
 	if (!test->session)
 		test->session = soup_test_session_new (SOUP_TYPE_SESSION, NULL);
 
-	jar = soup_cookie_jar_new ();
-	soup_session_add_feature (test->session, SOUP_SESSION_FEATURE (jar));
-	for (l = test->initial_cookies; l; l = g_list_next (l))
-		soup_cookie_jar_add_cookie (jar, (SoupCookie *)l->data);
-	g_clear_pointer (&test->initial_cookies, g_list_free);
-	g_object_unref (jar);
-
 	url = g_strdup_printf ("ws://127.0.0.1:%u/unix", test->port);
 	test->msg = soup_message_new ("GET", url);
 	g_free (url);
@@ -302,21 +291,6 @@ on_text_message (SoupWebsocketConnection *ws,
 	*receive = g_bytes_ref (message);
 }
 
-static void
-on_binary_message (SoupWebsocketConnection *ws,
-		   SoupWebsocketDataType type,
-		   GBytes *message,
-		   gpointer user_data)
-{
-	GBytes **receive = user_data;
-
-	g_assert_cmpint (type, ==, SOUP_WEBSOCKET_DATA_BINARY);
-	g_assert (*receive == NULL);
-	g_assert (message != NULL);
-
-	*receive = g_bytes_ref (message);
-}
-
 static void
 on_close_set_flag (SoupWebsocketConnection *ws,
                    gpointer user_data)
@@ -470,37 +444,6 @@ test_send_big_packets (Test *test,
 	g_bytes_unref (received);
 }
 
-static void
-test_send_empty_packets (Test *test,
-			 gconstpointer data)
-{
-	GBytes *received = NULL;
-	gulong id;
-
-	id = g_signal_connect (test->client, "message", G_CALLBACK (on_text_message), &received);
-
-	soup_websocket_connection_send_text (test->server, "\0");
-	WAIT_UNTIL (received != NULL);
-	g_assert_nonnull (g_bytes_get_data (received, NULL));
-	g_assert_cmpuint (((char *) g_bytes_get_data (received, NULL))[0], ==, '\0');
-	g_assert_cmpuint (g_bytes_get_size (received), ==, 0);
-	g_bytes_unref (received);
-	received = NULL;
-	g_signal_handler_disconnect (test->client, id);
-
-	id = g_signal_connect (test->client, "message", G_CALLBACK (on_binary_message), &received);
-
-	soup_websocket_connection_send_binary (test->server, NULL, 0);
-	WAIT_UNTIL (received != NULL);
-	/* We always include at least a null character */
-	g_assert_nonnull (g_bytes_get_data (received, NULL));
-	g_assert_cmpuint (((char *) g_bytes_get_data (received, NULL))[0], ==, '\0');
-	g_assert_cmpuint (g_bytes_get_size (received), ==, 0);
-	g_bytes_unref (received);
-	received = NULL;
-	g_signal_handler_disconnect (test->client, id);
-}
-
 static void
 test_send_bad_data (Test *test,
                     gconstpointer unused)
@@ -509,27 +452,24 @@ test_send_bad_data (Test *test,
 	GIOStream *io;
 	gsize written;
 	const char *frame;
-	gboolean close_event = FALSE;
 
 	g_signal_handlers_disconnect_by_func (test->server, on_error_not_reached, NULL);
 	g_signal_connect (test->server, "error", G_CALLBACK (on_error_copy), &error);
-	g_signal_connect (test->client, "closed", G_CALLBACK (on_close_set_flag), &close_event);
 
 	io = soup_websocket_connection_get_io_stream (test->client);
 
 	/* Bad UTF-8 frame */
-	frame = "\x81\x84\x00\x00\x00\x00\xEE\xEE\xEE\xEE";
+	frame = "\x81\x04\xEE\xEE\xEE\xEE";
 	if (!g_output_stream_write_all (g_io_stream_get_output_stream (io),
-					frame, 10, &written, NULL, NULL))
+					frame, 6, &written, NULL, NULL))
 		g_assert_not_reached ();
-	g_assert_cmpuint (written, ==, 10);
+	g_assert_cmpuint (written, ==, 6);
 
 	WAIT_UNTIL (error != NULL);
 	g_assert_error (error, SOUP_WEBSOCKET_ERROR, SOUP_WEBSOCKET_CLOSE_BAD_DATA);
 	g_clear_error (&error);
 
 	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
-	g_assert (close_event);
 
 	g_assert_cmpuint (soup_websocket_connection_get_close_code (test->client), ==, SOUP_WEBSOCKET_CLOSE_BAD_DATA);
 }
@@ -725,28 +665,9 @@ test_protocol_client_any_soup (Test *test,
 	g_assert_cmpstr (soup_message_headers_get_one (test->msg->response_headers, "Sec-WebSocket-Protocol"), ==, NULL);
 }
 
-static const struct {
-	gushort code;
-	const char *reason;
-	gushort expected_sender_code;
-	const char *expected_sender_reason;
-	gushort expected_receiver_code;
-	const char *expected_receiver_reason;
-} close_clean_tests[] = {
-	{ SOUP_WEBSOCKET_CLOSE_NORMAL, "NORMAL", SOUP_WEBSOCKET_CLOSE_NORMAL, "NORMAL", SOUP_WEBSOCKET_CLOSE_NORMAL, "NORMAL" },
-	{ SOUP_WEBSOCKET_CLOSE_GOING_AWAY, "GOING_AWAY", SOUP_WEBSOCKET_CLOSE_GOING_AWAY, "GOING_AWAY", SOUP_WEBSOCKET_CLOSE_GOING_AWAY, "GOING_AWAY" },
-	{ SOUP_WEBSOCKET_CLOSE_NORMAL, NULL, SOUP_WEBSOCKET_CLOSE_NORMAL, NULL, SOUP_WEBSOCKET_CLOSE_NORMAL, NULL },
-	{ SOUP_WEBSOCKET_CLOSE_NO_STATUS, NULL, SOUP_WEBSOCKET_CLOSE_NORMAL, NULL, SOUP_WEBSOCKET_CLOSE_NO_STATUS, NULL },
-};
-
 static void
-do_close_clean_client (Test *test,
-		       gushort code,
-		       const char *reason,
-		       gushort expected_sender_code,
-		       const char *expected_sender_reason,
-		       gushort expected_receiver_code,
-		       const char *expected_receiver_reason)
+test_close_clean_client (Test *test,
+                         gconstpointer data)
 {
 	gboolean close_event_client = FALSE;
 	gboolean close_event_server = FALSE;
@@ -754,7 +675,7 @@ do_close_clean_client (Test *test,
 	g_signal_connect (test->client, "closed", G_CALLBACK (on_close_set_flag), &close_event_client);
 	g_signal_connect (test->server, "closed", G_CALLBACK (on_close_set_flag), &close_event_server);
 
-	soup_websocket_connection_close (test->client, code, reason);
+	soup_websocket_connection_close (test->client, SOUP_WEBSOCKET_CLOSE_GOING_AWAY, "give me a reason");
 	g_assert_cmpint (soup_websocket_connection_get_state (test->client), ==, SOUP_WEBSOCKET_STATE_CLOSING);
 
 	WAIT_UNTIL (soup_websocket_connection_get_state (test->server) == SOUP_WEBSOCKET_STATE_CLOSED);
@@ -763,62 +684,14 @@ do_close_clean_client (Test *test,
 	g_assert (close_event_client);
 	g_assert (close_event_server);
 
-	g_assert_cmpint (soup_websocket_connection_get_close_code (test->client), ==, expected_sender_code);
-	g_assert_cmpstr (soup_websocket_connection_get_close_data (test->client), ==, expected_sender_reason);
-	g_assert_cmpint (soup_websocket_connection_get_close_code (test->server), ==, expected_receiver_code);
-	g_assert_cmpstr (soup_websocket_connection_get_close_data (test->server), ==, expected_receiver_reason);
+	g_assert_cmpint (soup_websocket_connection_get_close_code (test->client), ==, SOUP_WEBSOCKET_CLOSE_GOING_AWAY);
+	g_assert_cmpint (soup_websocket_connection_get_close_code (test->server), ==, SOUP_WEBSOCKET_CLOSE_GOING_AWAY);
+	g_assert_cmpstr (soup_websocket_connection_get_close_data (test->server), ==, "give me a reason");
 }
 
 static void
-test_close_clean_client_soup (Test *test,
-			      gconstpointer data)
-{
-	guint i;
-
-	for (i = 0; i < G_N_ELEMENTS (close_clean_tests); i++) {
-		setup_soup_connection (test, data);
-
-		do_close_clean_client (test,
-				       close_clean_tests[i].code,
-				       close_clean_tests[i].reason,
-				       close_clean_tests[i].expected_sender_code,
-				       close_clean_tests[i].expected_sender_reason,
-				       close_clean_tests[i].expected_receiver_code,
-				       close_clean_tests[i].expected_receiver_reason);
-
-		teardown_soup_connection (test, data);
-	}
-}
-
-static void
-test_close_clean_client_direct (Test *test,
-				gconstpointer data)
-{
-	guint i;
-
-	for (i = 0; i < G_N_ELEMENTS (close_clean_tests); i++) {
-		setup_direct_connection (test, data);
-
-		do_close_clean_client (test,
-				       close_clean_tests[i].code,
-				       close_clean_tests[i].reason,
-				       close_clean_tests[i].expected_sender_code,
-				       close_clean_tests[i].expected_sender_reason,
-				       close_clean_tests[i].expected_receiver_code,
-				       close_clean_tests[i].expected_receiver_reason);
-
-		teardown_direct_connection (test, data);
-	}
-}
-
-static void
-do_close_clean_server (Test *test,
-		       gushort code,
-		       const char *reason,
-		       gushort expected_sender_code,
-		       const char *expected_sender_reason,
-		       gushort expected_receiver_code,
-		       const char *expected_receiver_reason)
+test_close_clean_server (Test *test,
+                         gconstpointer data)
 {
 	gboolean close_event_client = FALSE;
 	gboolean close_event_server = FALSE;
@@ -826,7 +699,7 @@ do_close_clean_server (Test *test,
 	g_signal_connect (test->client, "closed", G_CALLBACK (on_close_set_flag), &close_event_client);
 	g_signal_connect (test->server, "closed", G_CALLBACK (on_close_set_flag), &close_event_server);
 
-	soup_websocket_connection_close (test->server, code, reason);
+	soup_websocket_connection_close (test->server, SOUP_WEBSOCKET_CLOSE_GOING_AWAY, "another reason");
 	g_assert_cmpint (soup_websocket_connection_get_state (test->server), ==, SOUP_WEBSOCKET_STATE_CLOSING);
 
 	WAIT_UNTIL (soup_websocket_connection_get_state (test->server) == SOUP_WEBSOCKET_STATE_CLOSED);
@@ -835,52 +708,9 @@ do_close_clean_server (Test *test,
 	g_assert (close_event_client);
 	g_assert (close_event_server);
 
-	g_assert_cmpint (soup_websocket_connection_get_close_code (test->server), ==, expected_sender_code);
-	g_assert_cmpstr (soup_websocket_connection_get_close_data (test->server), ==, expected_sender_reason);
-	g_assert_cmpint (soup_websocket_connection_get_close_code (test->client), ==, expected_receiver_code);
-	g_assert_cmpstr (soup_websocket_connection_get_close_data (test->client), ==, expected_receiver_reason);
-}
-
-static void
-test_close_clean_server_soup (Test *test,
-			      gconstpointer data)
-{
-	guint i;
-
-	for (i = 0; i < G_N_ELEMENTS (close_clean_tests); i++) {
-		setup_direct_connection (test, data);
-
-		do_close_clean_server (test,
-				       close_clean_tests[i].code,
-				       close_clean_tests[i].reason,
-				       close_clean_tests[i].expected_sender_code,
-				       close_clean_tests[i].expected_sender_reason,
-				       close_clean_tests[i].expected_receiver_code,
-				       close_clean_tests[i].expected_receiver_reason);
-
-		teardown_direct_connection (test, data);
-	}
-}
-
-static void
-test_close_clean_server_direct (Test *test,
-				gconstpointer data)
-{
-	guint i;
-
-	for (i = 0; i < G_N_ELEMENTS (close_clean_tests); i++) {
-		setup_direct_connection (test, data);
-
-		do_close_clean_server (test,
-				       close_clean_tests[i].code,
-				       close_clean_tests[i].reason,
-				       close_clean_tests[i].expected_sender_code,
-				       close_clean_tests[i].expected_sender_reason,
-				       close_clean_tests[i].expected_receiver_code,
-				       close_clean_tests[i].expected_receiver_reason);
-
-		teardown_direct_connection (test, data);
-	}
+	g_assert_cmpint (soup_websocket_connection_get_close_code (test->server), ==, SOUP_WEBSOCKET_CLOSE_GOING_AWAY);
+	g_assert_cmpint (soup_websocket_connection_get_close_code (test->client), ==, SOUP_WEBSOCKET_CLOSE_GOING_AWAY);
+	g_assert_cmpstr (soup_websocket_connection_get_close_data (test->client), ==, "another reason");
 }
 
 static gboolean
@@ -925,80 +755,6 @@ test_message_after_closing (Test *test,
 	g_bytes_unref (message);
 }
 
-static gpointer
-close_after_close_server_thread (gpointer user_data)
-{
-	Test *test = user_data;
-	gsize written;
-	const char frames[] =
-		"\x88\x09\x03\xe8""reason1"
-		"\x88\x09\x03\xe8""reason2";
-	GSocket *socket;
-	GError *error = NULL;
-
-	g_mutex_lock (&test->mutex);
-	g_mutex_unlock (&test->mutex);
-
-	g_output_stream_write_all (g_io_stream_get_output_stream (test->raw_server),
-				   frames, sizeof (frames) -1, &written, NULL, &error);
-	g_assert_no_error (error);
-	g_assert_cmpuint (written, ==, sizeof (frames) - 1);
-	socket = g_socket_connection_get_socket (G_SOCKET_CONNECTION (test->raw_server));
-	g_socket_shutdown (socket, FALSE, TRUE, &error);
-	g_assert_no_error (error);
-
-	return NULL;
-}
-
-static void
-test_close_after_close (Test *test,
-			gconstpointer data)
-{
-	GThread *thread;
-
-	g_mutex_lock (&test->mutex);
-
-	thread = g_thread_new ("close-after-close-thread", close_after_close_server_thread, test);
-
-	soup_websocket_connection_close (test->client, SOUP_WEBSOCKET_CLOSE_NORMAL, "reason1");
-	g_mutex_unlock (&test->mutex);
-
-	g_thread_join (thread);
-
-	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
-	g_assert_cmpuint (soup_websocket_connection_get_close_code (test->client), ==, SOUP_WEBSOCKET_CLOSE_NORMAL);
-	g_assert_cmpstr (soup_websocket_connection_get_close_data (test->client), ==, "reason1");
-	g_io_stream_close (test->raw_server, NULL, NULL);
-}
-
-static gboolean
-on_close_unref_connection (SoupWebsocketConnection *ws,
-			   gpointer user_data)
-{
-	Test *test = user_data;
-
-	g_assert_true (test->server == ws);
-	g_clear_object (&test->server);
-	return TRUE;
-}
-
-static void
-test_server_unref_connection_on_close (Test *test,
-				       gconstpointer data)
-{
-	gboolean close_event_client = FALSE;
-
-	g_signal_connect (test->client, "closed", G_CALLBACK (on_close_set_flag), &close_event_client);
-	g_signal_connect (test->server, "closed", G_CALLBACK (on_close_unref_connection), test);
-	soup_websocket_connection_close (test->client, SOUP_WEBSOCKET_CLOSE_GOING_AWAY, "client closed");
-	g_assert_cmpint (soup_websocket_connection_get_state (test->client), ==, SOUP_WEBSOCKET_STATE_CLOSING);
-
-	WAIT_UNTIL (test->server == NULL);
-	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
-
-	g_assert_true (close_event_client);
-}
-
 static gpointer
 timeout_server_thread (gpointer user_data)
 {
@@ -1087,175 +843,6 @@ test_receive_fragmented (Test *test,
 	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
 }
 
-typedef struct {
-	Test *test;
-	const char *header;
-	GString *payload;
-} InvalidEncodeLengthTest;
-
-static gpointer
-send_invalid_encode_length_server_thread (gpointer user_data)
-{
-	InvalidEncodeLengthTest *test = user_data;
-	gsize header_size;
-	gsize written;
-	GError *error = NULL;
-
-	header_size = test->payload->len == 125 ? 6 : 10;
-	g_output_stream_write_all (g_io_stream_get_output_stream (test->test->raw_server),
-				   test->header, header_size, &written, NULL, &error);
-	g_assert_no_error (error);
-	g_assert_cmpuint (written, ==, header_size);
-
-	g_output_stream_write_all (g_io_stream_get_output_stream (test->test->raw_server),
-				   test->payload->str, test->payload->len, &written, NULL, &error);
-	g_assert_no_error (error);
-	g_assert_cmpuint (written, ==, test->payload->len);
-
-	g_io_stream_close (test->test->raw_server, NULL, &error);
-	g_assert_no_error (error);
-
-	return NULL;
-}
-
-static void
-test_receive_invalid_encode_length_16 (Test *test,
-				       gconstpointer data)
-{
-	GThread *thread;
-	GBytes *received = NULL;
-	GError *error = NULL;
-	InvalidEncodeLengthTest context = { test, NULL };
-	guint i;
-
-	g_signal_connect (test->client, "error", G_CALLBACK (on_error_copy), &error);
-	g_signal_connect (test->client, "message", G_CALLBACK (on_binary_message), &received);
-
-	/* We use 126(~) as payload length with 125 extended length */
-	context.header = "\x82~\x00}";
-	context.payload = g_string_new (NULL);
-	for (i = 0; i < 125; i++)
-		g_string_append (context.payload, "X");
-	thread = g_thread_new ("invalid-encode-length-thread", send_invalid_encode_length_server_thread, &context);
-
-	WAIT_UNTIL (error != NULL || received != NULL);
-	g_assert_error (error, SOUP_WEBSOCKET_ERROR, SOUP_WEBSOCKET_CLOSE_PROTOCOL_ERROR);
-	g_clear_error (&error);
-	g_assert_null (received);
-
-	g_thread_join (thread);
-	g_string_free (context.payload, TRUE);
-
-	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
-}
-
-static void
-test_receive_invalid_encode_length_64 (Test *test,
-				       gconstpointer data)
-{
-	GThread *thread;
-	GBytes *received = NULL;
-	GError *error = NULL;
-	InvalidEncodeLengthTest context = { test, NULL };
-	guint i;
-
-	g_signal_connect (test->client, "error", G_CALLBACK (on_error_copy), &error);
-	g_signal_connect (test->client, "message", G_CALLBACK (on_binary_message), &received);
-
-	/* We use 127(\x7f) as payload length with 65535 extended length */
-	context.header = "\x82\x7f\x00\x00\x00\x00\x00\x00\xff\xff";
-	context.payload = g_string_new (NULL);
-	for (i = 0; i < 65535; i++)
-		g_string_append (context.payload, "X");
-	thread = g_thread_new ("invalid-encode-length-thread", send_invalid_encode_length_server_thread, &context);
-
-	WAIT_UNTIL (error != NULL || received != NULL);
-	g_assert_error (error, SOUP_WEBSOCKET_ERROR, SOUP_WEBSOCKET_CLOSE_PROTOCOL_ERROR);
-	g_clear_error (&error);
-	g_assert_null (received);
-
-        g_thread_join (thread);
-	g_string_free (context.payload, TRUE);
-
-	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
-}
-
-static gpointer
-send_masked_frame_server_thread (gpointer user_data)
-{
-	Test *test = user_data;
-	const char frame[] = "\x82\x8e\x9a";
-	gsize written;
-	GError *error = NULL;
-
-	g_output_stream_write_all (g_io_stream_get_output_stream (test->raw_server),
-				   frame, sizeof (frame), &written, NULL, &error);
-	g_assert_no_error (error);
-	g_assert_cmpuint (written, ==, sizeof (frame));
-
-	g_io_stream_close (test->raw_server, NULL, &error);
-	g_assert_no_error (error);
-
-	return NULL;
-}
-
-static void
-test_client_receive_masked_frame (Test *test,
-				  gconstpointer data)
-{
-	GThread *thread;
-	GBytes *received = NULL;
-	GError *error = NULL;
-
-	g_signal_connect (test->client, "error", G_CALLBACK (on_error_copy), &error);
-	g_signal_connect (test->client, "message", G_CALLBACK (on_binary_message), &received);
-
-	thread = g_thread_new ("send-masked-frame-thread", send_masked_frame_server_thread, test);
-
-	WAIT_UNTIL (error != NULL || received != NULL);
-	g_assert_error (error, SOUP_WEBSOCKET_ERROR, SOUP_WEBSOCKET_CLOSE_PROTOCOL_ERROR);
-	g_clear_error (&error);
-	g_assert_null (received);
-
-        g_thread_join (thread);
-
-	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
-}
-
-static void
-test_server_receive_unmasked_frame (Test *test,
-				    gconstpointer data)
-{
-	GError *error = NULL;
-	GIOStream *io;
-	gsize written;
-	const char *frame;
-	gboolean close_event = FALSE;
-
-	g_signal_handlers_disconnect_by_func (test->server, on_error_not_reached, NULL);
-	g_signal_connect (test->server, "error", G_CALLBACK (on_error_copy), &error);
-	g_signal_connect (test->client, "closed", G_CALLBACK (on_close_set_flag), &close_event);
-
-	io = soup_websocket_connection_get_io_stream (test->client);
-
-	/* Unmasked frame */
-	frame = "\x81\x0bHello World";
-	if (!g_output_stream_write_all (g_io_stream_get_output_stream (io),
-					frame, 13, &written, NULL, NULL))
-		g_assert_not_reached ();
-	g_assert_cmpuint (written, ==, 13);
-
-	WAIT_UNTIL (error != NULL);
-	g_assert_error (error, SOUP_WEBSOCKET_ERROR, SOUP_WEBSOCKET_CLOSE_PROTOCOL_ERROR);
-	g_clear_error (&error);
-
-	WAIT_UNTIL (soup_websocket_connection_get_state (test->client) == SOUP_WEBSOCKET_STATE_CLOSED);
-	g_assert (close_event);
-
-	g_assert_cmpuint (soup_websocket_connection_get_close_code (test->client), ==, SOUP_WEBSOCKET_CLOSE_PROTOCOL_ERROR);
-
-}
-
 static void
 test_client_context_got_server_connection (SoupServer              *server,
 					   SoupWebsocketConnection *connection,
@@ -1304,64 +891,6 @@ test_client_context (Test *test,
 	g_assert_no_error (test->client_error);
 }
 
-static void
-test_cookies_in_request (Test *test,
-                         gconstpointer data)
-{
-        SoupCookie *cookie;
-        const char *cookie_header;
-        SoupCookie *requested_cookie;
-
-        cookie = soup_cookie_new ("foo", "bar", "127.0.0.1", "/", -1);
-        test->initial_cookies = g_list_prepend (test->initial_cookies, soup_cookie_copy (cookie));
-
-        setup_soup_server (test, NULL, NULL, got_server_connection, test);
-        client_connect (test, NULL, NULL, got_client_connection, test);
-        WAIT_UNTIL (test->server != NULL);
-        WAIT_UNTIL (test->client != NULL || test->client_error != NULL);
-        g_assert_no_error (test->client_error);
-
-        cookie_header = soup_message_headers_get_one (test->msg->request_headers, "Cookie");
-        requested_cookie = soup_cookie_parse (cookie_header, NULL);
-        g_assert_true (soup_cookie_equal (cookie, requested_cookie));
-        soup_cookie_free (cookie);
-        soup_cookie_free (requested_cookie);
-}
-
-static void
-cookies_test_websocket_server_request_started (SoupServer *server, SoupMessage *msg,
-                                               SoupClientContext *client, gpointer user_data)
-{
-        soup_message_headers_append (msg->response_headers, "Set-Cookie", "foo=bar; Path=/");
-}
-
-static void
-test_cookies_in_response (Test *test,
-                          gconstpointer data)
-{
-        SoupCookieJar *jar;
-        GSList *cookies;
-        SoupCookie *cookie;
-
-        setup_soup_server (test, NULL, NULL, got_server_connection, test);
-        g_signal_connect (test->soup_server, "request-started",
-                          G_CALLBACK (cookies_test_websocket_server_request_started),
-                          NULL);
-        client_connect (test, NULL, NULL, got_client_connection, test);
-        WAIT_UNTIL (test->server != NULL);
-        WAIT_UNTIL (test->client != NULL || test->client_error != NULL);
-        g_assert_no_error (test->client_error);
-
-        jar = SOUP_COOKIE_JAR (soup_session_get_feature (test->session, SOUP_TYPE_COOKIE_JAR));
-        cookies = soup_cookie_jar_all_cookies (jar);
-        g_assert_nonnull (cookies);
-        g_assert_cmpuint (g_slist_length (cookies), ==, 1);
-        cookie = soup_cookie_new ("foo", "bar", "127.0.0.1", "/", -1);
-        g_assert_true (soup_cookie_equal (cookie, (SoupCookie *)cookies->data));
-        g_slist_free_full (cookies, (GDestroyNotify)soup_cookie_free);
-        soup_cookie_free (cookie);
-}
-
 int
 main (int argc,
       char *argv[])
@@ -1406,15 +935,6 @@ main (int argc,
 		    test_send_big_packets,
 		    teardown_soup_connection);
 
-	g_test_add ("/websocket/direct/send-empty-packets", Test, NULL,
-		    setup_direct_connection,
-		    test_send_empty_packets,
-		    teardown_direct_connection);
-	g_test_add ("/websocket/soup/send-empty-packets", Test, NULL,
-		    setup_soup_connection,
-		    test_send_empty_packets,
-		    teardown_soup_connection);
-
 	g_test_add ("/websocket/direct/send-bad-data", Test, NULL,
 		    setup_direct_connection,
 		    test_send_bad_data,
@@ -1424,19 +944,23 @@ main (int argc,
 		    test_send_bad_data,
 		    teardown_soup_connection);
 
-	g_test_add ("/websocket/direct/close-clean-client", Test, NULL, NULL,
-		    test_close_clean_client_direct,
-		    NULL);
-	g_test_add ("/websocket/soup/close-clean-client", Test, NULL, NULL,
-		    test_close_clean_client_soup,
-		    NULL);
+	g_test_add ("/websocket/direct/close-clean-client", Test, NULL,
+		    setup_direct_connection,
+		    test_close_clean_client,
+		    teardown_direct_connection);
+	g_test_add ("/websocket/soup/close-clean-client", Test, NULL,
+		    setup_soup_connection,
+		    test_close_clean_client,
+		    teardown_soup_connection);
 
-	g_test_add ("/websocket/direct/close-clean-server", Test, NULL, NULL,
-		    test_close_clean_server_direct,
-		    NULL);
-	g_test_add ("/websocket/soup/close-clean-server", Test, NULL, NULL,
-		    test_close_clean_server_soup,
-		    NULL);
+	g_test_add ("/websocket/direct/close-clean-server", Test, NULL,
+		    setup_direct_connection,
+		    test_close_clean_server,
+		    teardown_direct_connection);
+	g_test_add ("/websocket/soup/close-clean-server", Test, NULL,
+		    setup_soup_connection,
+		    test_close_clean_server,
+		    teardown_soup_connection);
 
 	g_test_add ("/websocket/direct/message-after-closing", Test, NULL,
 		    setup_direct_connection,
@@ -1447,16 +971,6 @@ main (int argc,
 		    test_message_after_closing,
 		    teardown_soup_connection);
 
-	g_test_add ("/websocket/direct/close-after-close", Test, NULL,
-		    setup_half_direct_connection,
-		    test_close_after_close,
-		    teardown_direct_connection);
-
-	g_test_add ("/websocket/soup/server-unref-connection-on-close", Test, NULL,
-		    setup_soup_connection,
-		    test_server_unref_connection_on_close,
-		    teardown_soup_connection);
-
 
 	g_test_add ("/websocket/direct/protocol-negotiate", Test, NULL, NULL,
 		    test_protocol_negotiate_direct,
@@ -1492,30 +1006,6 @@ main (int argc,
 		    test_receive_fragmented,
 		    teardown_direct_connection);
 
-	g_test_add ("/websocket/direct/receive-invalid-encode-length-16", Test, NULL,
-		    setup_half_direct_connection,
-		    test_receive_invalid_encode_length_16,
-		    teardown_direct_connection);
-
-	g_test_add ("/websocket/direct/receive-invalid-encode-length-64", Test, NULL,
-		    setup_half_direct_connection,
-		    test_receive_invalid_encode_length_64,
-		    teardown_direct_connection);
-
-	g_test_add ("/websocket/direct/client-receive-masked-frame", Test, NULL,
-		    setup_half_direct_connection,
-		    test_client_receive_masked_frame,
-		    teardown_direct_connection);
-
-	g_test_add ("/websocket/direct/server-receive-unmasked-frame", Test, NULL,
-		    setup_direct_connection,
-		    test_server_receive_unmasked_frame,
-		    teardown_direct_connection);
-	g_test_add ("/websocket/soup/server-receive-unmasked-frame", Test, NULL,
-		    setup_soup_connection,
-		    test_server_receive_unmasked_frame,
-		    teardown_soup_connection);
-
 	if (g_test_slow ()) {
 		g_test_add ("/websocket/direct/close-after-timeout", Test, NULL,
 			    setup_half_direct_connection,
@@ -1527,13 +1017,6 @@ main (int argc,
 		    test_client_context,
 		    teardown_soup_connection);
 
-        g_test_add ("/websocket/soup/cookies-in-request", Test, NULL, NULL,
-                    test_cookies_in_request,
-                    teardown_soup_connection);
-        g_test_add ("/websocket/soup/cookies-in-response", Test, NULL, NULL,
-                    test_cookies_in_response,
-                    teardown_soup_connection);
-
 	ret = g_test_run ();
 
 	test_cleanup ();
